CREATE OR REPLACE VIEW TrainedModelView AS
SELECT
    id,
    chain,
    name,
    feed,
    symbols,
    model_type,
    r2,
    rmse,
    feature_count,
    target,
    scaler_mean,
    scaler_scale,
    coefficients,
    intercept,
    performance,
    ranking,
    last_evaluation_voting_round,
    last_evaluation_time,
    running,
    predicting,
    running_r_squared,
    directional_accuracy,
    overestimation_frequency,
    underestimation_frequency,
    average_overestimation_degree,
    average_underestimation_degree,
    correction_factor,
    avg_correction_error,
    avg_last_n_corrections,
    mae,
    rmse_metric,
    mape,
    prediction_stability,
    complexity_penalty,
    timestamp
FROM
    TrainedModel;